<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK" sourcelanguage="en">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>Ak sa chcete vrátiť do aplikácie, kliknite sem</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>0 Items</source>
        <translation>0 položiek</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>Vymazať všetko</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Stiahnuté súbory</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>Formulár</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otvoriť</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zastaviť</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Názov súboru</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Skúsiť znova</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Title</source>
        <translation>Názov</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publikovať podcast na YouTube</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Add</source>
        <translation>Pridať</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Vymazať</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Vystrihnúť</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Pero</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>Back</source>
        <translatorcomment>oproti reťazcu ďalšia strana</translatorcomment>
        <translation>Predošlá</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovať</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Tmavá</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>Ruka</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Úvodná stránka</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Doľava</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Čiara</translation>
    </message>
    <message>
        <source>Next</source>
        <translatorcomment>strana</translatorcomment>
        <translation>Ďalšia</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Opakovať zmenu</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Skončiť</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Odvolať zmenu</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>Zobraziť tabuľu</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>Tabuľa</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Farba</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>Vygumovať</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>Zobraziť nástroje</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Svetlá</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>Vložiť obsah z webu</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Stránky</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Prilepiť</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pozastaviť</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Doprava</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>Uspať</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Nástroje</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>Viac obrazoviek</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>Uspať prezentáciu</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>Nový dokument</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>Úplne tmavé pozadie</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>Nastavenia podcastu</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Vyhľadať aktualizáciu</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>Použiť vlastnú veľkosť dokumentu</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Zväčšiť</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>Nahrať prezentáciu na video</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>Mriežka s tmavým pozadím</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>Veľká guma</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>Mriežka so svetlým pozadím</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>Schovať aplikáciu OpenBoard</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>Nahrať externú stránku</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Pridať záložku</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>Vyčistiť všetky objekty</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Posunúť sa po stránke</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>Tenká čiara</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Knižnica</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>Nastaviť nahrávanie podcastu</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>Otvoriť stránku na tabuli</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>Zväčšiť</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Vymazať</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>Guma</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportovať</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nový priečinok</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation>Označiť obsah vo Flashi</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Nahrať</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>Vlastný spôsob označenia</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Zvýrazňovač</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>Vytvoriť nový dokument</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Nahrávať</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Obnoviť</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Premenovať</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>Dotykové pero</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>Skončiť OpenBoard</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>Vlastná veľkosť</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>Laserové ukazovadlo</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>Na šírku (16/9)</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>Nahrať úvodnú stránku</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>Duplikovať stránku</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>Duplikovať vybraný obsah</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Záložky</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>Otvoriť na tabuli</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>Premenovať obsah</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Zmenšiť</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>Záložka</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>Pridať na aktuálnu stránku</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>Vytvoriť novú stránku</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>Schovať OpenBoard</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>Vygumovať všetky položky</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>Vygumovať obsah</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>Vygumovať položky</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplikovať</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>Pridať vybraný obsah do otvoreného dokumentu</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Virtuálna klávesnica</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>Zobraziť knižnicu</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>Stredne veľká guma</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>Zastaviť nahrávanie webovej stránky</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>Duplikovať aktuálnu stránku</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>Pozastaviť nahrávanie podcastu</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>Vytvoriť nový priečinok</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>Vyčistiť stránku</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>Pridať do knižnice</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Predošlá</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>Zastaviť nahrávanie</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>Obnoviť aktuálnu stránku</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>Nahrať stránku</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>Kresliť čiary</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Označiť</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>V zobrazenej časti obrazovky zobraziť hlavnú obrazovku</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation>Označiť Flash</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>Označiť okno</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>Vymazať vybraný obsah</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>Pridať položku na novú stránku</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>Pridať obsah do dokumentu</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>Zmenšiť</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>Označiť obsah z internetu, ktorý sa dá vložiť</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>Písať text</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>Pridať na novú stránku</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>Bežná veľkosť (4/3)</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>Označiť web</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>Zobraziť virtuálnu klávesnicu</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>Zobraziť záložky</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>Zobraziť na šírku dokumentu (16/9)</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>Zobraziť pracovnú plochu</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedia</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>Stredne hrubá čiara</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Predchádzajúca stránka</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>Označiť obsah z webu</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>Oddeľovač</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>Vygumovať všetky poznámky</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>Vygumovať všetky poznámky</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>Exportovať dokument</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>Spustiť nahrávanie obrazovky</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Nová stránka</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>Nahrať dokument</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>Nahrať simuláciu zo stránky eduMedia</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>Používať bežnú veľkosť dokumentu (4/3)</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>Zmeniť pozadie</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>Zobraziť predvoľby</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Predvoľby</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Označiť časť obrazovky</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Ďalšia</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>Riadiť dokumenty</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>Hrubá čiara</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>Vygumovať poznámky</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>Zobraziť pri projekcii</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>Vybrať a upraviť objekty</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>Označiť okno</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>Virtuálne laserové ukazovadlo</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>Úplne svetlé pozadie</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>Pridať položku do knižnice</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>Prehliadanie webu</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>Pozadia</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translatorcomment>spelling mistake in source: should be small</translatorcomment>
        <translation type="vanished">Malá guma</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>Pridať položku na aktuálnu stránku</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>Pridať do aktuálneho dokumentu</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>Zvýrazniť</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>Zobraziť pracovnú plochu</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Ďalšia stránka</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>Pridať poznámku do dokumentu</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>Vygumovať poznámku</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Prehrať</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>Manipulovať s položkami</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>Vygumovať pozadie</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translatorcomment>spelling mistake: should be background</translatorcomment>
        <translation>Odstrániť pozadie</translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation>Otvoriť príručku</translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation>Otvoriť webovú stránku príručky</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Vyžaduje sa prihlásenie</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Používateľské meno:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Save username and password for future use</source>
        <translation>Používateľské meno a heslo uložiť na použitie v budúcnosti</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>Pripojiť sa k proxy</translation>
    </message>
    <message>
        <source>Proxy Authentication</source>
        <translation>Prihlásenie na proxy</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Používateľské meno:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation>ID prvku =</translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation>Obsah nie je podporovaný v cieľovom formáte.</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation>Odstrániť stránku</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation>Určite chcete odstrániť 1 stránku z vybraného dokumentu &apos;%0&apos;?</translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Page Size</source>
        <translation>Veľkosť stránky</translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualizovať</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>Žiadna aktualizácia nie je k dispozícii</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>K dispozícii je nová aktualizácia. Chcete prejsť na webovú stránku?</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>K dispozícii je aktualizácia</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>All Supported (%1)</source>
        <translation>Všetky podporované (%1)</translation>
    </message>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>Nepodarilo sa stiahnuť %1</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>Neznámy typ obsahu (%1)</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>Pridať položku</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>Neznámy typ nástroja %1</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Sťahovanie bolo dokončené</translation>
    </message>
    <message>
        <source>Delete page %1 from document</source>
        <translation type="vanished">Vymazať stránku %1 z dokumentu</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation>Stránka %1 bola vymazaná</translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation>Nepodarilo sa pridať súbor: chyba pri kopírovaní súboru</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Zoskupiť</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>Oddeliť</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation>Dokument sa ukladá...</translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation>Dokument bol uložený.</translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished">Farba</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>Chyba pri pridávaní obrázka do knižnice</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>Označený obrázok</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Close</source>
        <translation>Zatvoriť</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Veľkosť:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Farba:</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>Tvar:</translation>
    </message>
    <message>
        <source>Cache Properties</source>
        <translation>Vlastnosti baterky</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>Zobraziť pracovnú plochu na druhej obrazovke</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>Označiť obrazovku</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>Zobraziť paletu pre interaktívne pero</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Označiť časť obrazovky</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>Zobraziť tabuľu na druhej obrazovke</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation>Zobraziť OpenBoard</translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>Empty</source>
        <translation>Vyprázdniť</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Kôš</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">Určite chcete vyprázdniť kôš?</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">Určite chcete odstrániť priečinok &quot;%1&quot; a celý jeho obsah?</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>Otvoriť podporovaný súbor</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">Odstrániť dokument</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>Všetky obrázky (%1)</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>Vo výbere nie je žiaden súbor obrázka!</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>Otvoriť dokument</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>Pridať priečinok s obrázkami</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Vymazať</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nový priečinok</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>Pridať obrázky</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>Duplikuje sa dokument %1</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>Stránka %1</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>Dokument %1 bol skopírovaný</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Nahráva sa súbor %1...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>Súbor sa nepodarilo nahrať...</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">Určite chcete odstrániť dokument &quot;%1&quot;?</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">Kôš bol vyprázdnený</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">Vyprázdniť kôš</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">Odstrániť priečinok</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">Odstrániť stránku</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">Nevybrali ste žiaden dokument!</translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>Nahrať všetky obrázky z priečinka</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">Vyprázdňuje sa kôš</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>Určite chcete odstrániť %n stránku z vybraného dokumentu %1?</numerusform>
            <numerusform>Určite chcete odstrániť %n stránky z vybraného dokumentu %1?</numerusform>
            <numerusform>Určite chcete odstrániť %n stránok z vybraného dokumentu %1?</numerusform>
        </translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>Pridať všetky obrázky do dokumentu</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>Pridať stránky zo súboru</translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation>V priečinku nie sú žiadne súbory obrázkov</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation>Dokumenty bez názvu</translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation>Dokument &apos;%1&apos; bol vytvorený v novšej verzii OpenBoardu (%2). Ak ho otvoríte v tejto, aktuálnej verzii, môže dôjsť k strate údajov. Chcete napriek tomu pokračovať?</translation>
    </message>
    <message>
        <source>Are you sure you want to remove all selected documents?</source>
        <translation type="vanished">Určite chcete odstrániť všetky vybrané dokumenty?</translation>
    </message>
    <message>
        <source>Remove multiple documents</source>
        <translation type="vanished">Odstránenie viacerých dokumentov</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>Všetky podporované súbory (*.%1)</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>objekty</translation>
    </message>
    <message>
        <source>images</source>
        <translation>obrázky</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>videá</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>widgety</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>Súbor %1 bol uložený</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation>Vkladá sa stránka %1 z(o) %2</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Nahrávanie bolo úspešné.</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation>Nahrávanie súboru %1 bolo úspešné.</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation>Nahráva sa súbor %1</translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>Stránka %0</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation type="unfinished">Prijať</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Zrušiť</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>Trash</source>
        <translation type="unfinished">Kôš</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 skopírovaná stránka</numerusform>
            <numerusform>%1 skopírované stránky</numerusform>
            <numerusform>%1 skopírovaných stránok</numerusform>
        </translation>
    </message>
    <message>
        <source>My documents</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 skopírovaná stránka</numerusform>
            <numerusform>%1 skopírované stránky</numerusform>
            <numerusform>%1 skopírovaných stránok</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="unfinished">Kopíruje sa stránka %1/%2</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="vanished">
            <numerusform>%1 skopírovaná stránka</numerusform>
            <numerusform>%1 skopírované stránky</numerusform>
            <numerusform>%1 skopírovaných stránok</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (kópia)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">Kopíruje sa stránka %1/%2</translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>Sťahujú sa súbory</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Stránka %0</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Stránka %0</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Warnings during export was appeared</source>
        <translation>Počas exportu sa objavili varovania</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">Exportuje sa dokument...</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished">Export zlyhal</translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="unfinished">Do vybraného umiestnenia sa nedá exportovať. Na uloženie súboru nemáte dostatočné oprávnenia.</translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="unfinished">Export sa nepodaril: do umiestnenia sa nedá zapisovať</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">Export bol úspešný.</translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>Exportovať do IWB</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>Exportovať ako súbor IWB</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Exportuje sa dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Export bol úspešný.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Export sa nepodaril.</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>Stránka</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>Exportovať ako súbor UBZ</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>Exportuje sa %1 %2 z(o) %3</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exportuje sa dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Export bol úspešný.</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation>Exportovať do formátu OpenBoard</translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="vanished">Export sa nepodaril: do umiestnenia sa nedá zapisovať</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="vanished">Export zlyhal</translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="vanished">Do vybraného umiestnenia sa nedá exportovať. Na uloženie súboru nemáte dostatočné oprávnenia.</translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">Exportuje sa dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">Export bol úspešný.</translation>
    </message>
    <message>
        <source>Failed to export...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exportovať ako súbor PDF</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exportovať do PDF</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exportuje sa dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Export bol úspešný.</translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="vanished">Export sa nepodaril: do umiestnenia sa nedá zapisovať</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="vanished">Export zlyhal</translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="vanished">Do vybraného umiestnenia sa nedá exportovať. Na uloženie súboru nemáte dostatočné oprávnenia.</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exportovať ako súbor PDF</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exportovať do PDF</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>Exportuje sa stránka %1 z(o) %2</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Exportuje sa dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Export bol úspešný.</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>Stránka</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Export zlyhal.</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>Exportovať ako webové dáta</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Exportuje sa dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Export bol úspešný.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>Exportovať do webového prehliadača</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>Pridať na stránku</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="vanished">Nastaviť ako pozadie</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>Pridať do knižnice</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>Informácie o objekte</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>Pridať do obľúbených položiek</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Zdieľať*</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Vyhľadať</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Vymazať</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>Späť do priečinka</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Odstrániť z obľúbených položiek</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>Vytvoriť nový priečinok</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>Znova prejsť systém súborov</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>NahranýObrázok</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation>Zvukové nahrávky</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Filmy</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="vanished">Animácie</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation>Interaktívne aktivity</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Aplikácie</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation>Geometrické útvary</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Obľúbené</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation>Vyhľadávanie na webe</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Kôš</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation>Prijať</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation>Zadajte názov nového priečinka</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation>Nahrávanie</translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Zamknuté</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Zobraziť na rozšírenej obrazovke</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Go to Content Source</source>
        <translation>Prejsť na zdroj</translation>
    </message>
    <message>
        <source>Locked</source>
        <translation>Zamknuté</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Zobraziť na rozšírenej obrazovke</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="unfinished">Nastaviť ako pozadie</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation>Nepodarilo sa identifikovať nástroj na prácu s médiom</translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation>Nepodporovaný typ média</translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation>Služba na prehratie média sa nenašla</translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation>Chyba média: </translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;Text napíšte sem&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>Farba textu</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>Dá sa upravovať</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation>Nahráva sa...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>Zamrznuté</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>Zmeniť ako nástroj</translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Importing file %1...</source>
        <translation>Nahráva sa súbor %1...</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>Nahrávanie zlyhalo.</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Nepodarilo sa nahrať súbor %1.</translation>
    </message>
    <message>
        <source>Common File Format (</source>
        <translation>Bežný formát súboru (</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Nahrávanie bolo úspešné.</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>Nahráva sa súbor %1...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Nepodarilo sa nahrať súbor %1.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Nahrávanie bolo úspešné.</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation>OpenBoard (*.ubz)</translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>Súbor obrázka (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>PDF import failed.</source>
        <translation>Nahrávanie do PDF zlyhalo.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>Nahráva sa stránka %1 z(o) %2</translation>
    </message>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Portable Document Format (*.pdf)</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>Prebieha publikovanie na intranet %1 %</translation>
    </message>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>Chyba pri publikovaní videa na intranet (%1)</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>Publikovať</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Áno</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation>Zatvoriť</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Áno</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Zadajte používateľské meno a heslo pre &quot;%1&quot; na %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>Nepodarilo sa prihlásiť na proxy</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>Chyby SSL:

%1

%2

Chcete ignorovať tieto chyby na tomto serveri?</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation>Našli sa dokumenty Open-Sankoré</translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation>Tento panel zobraziť aj nabudúce</translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation>Nahrávanie dokumentov môžete kedykoľvek spustiť z karty O programe na paneli Predvoľby. Pozor, ak ste už nahrali dáta z Open-Sankoré, môžete ich spúšťať ako dokumenty vytvorené v OpenBoarde.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation>Pokračovať</translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation>Vo vašom počítači sa nachádzajú dokumenty Open-Sankoré. Do OpenBoardu ich môžete nahrať stlačením tlačidla Pokračovať, ktorým sa spustí aplikácia na nahrávanie.</translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(kópia)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>Strata úložiska dokumentov</translation>
    </message>
    <message>
        <source>has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="vanished">stratil prístup k úložisku dokumentov &apos;%1&apos;. Aplikácia sa musí zatvoriť, aby sa predišlo poškodeniu dát. Možno nebudú uložené ani najnovšie zmeny.</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>Angličtina</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Ruština</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Nemčina</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Francúzština</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>Švajčiarska francúzština</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Full</source>
        <translation>Vysoké rozlíšenie</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Nízke rozlíšenie</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>Chyba pri nahrávaní podcastu (%1)</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>Žiaden kódovač podcastu nie je k dispozícii.</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translatorcomment>inconsistent: elswhere written as YouTube</translatorcomment>
        <translation>Publikovať na Youtube</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Stredne vysoké rozlíšenie</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>v priečinku %1</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>Časť %1</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>Podcast vytvorený %1</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>Žiadna zvuková nahrávka</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>Publikovať na intranet</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>na vašu pracovnú plochu...</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>Predvolený vstup pre zvuk</translation>
    </message>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>Nepodarilo sa spustiť kódovač...</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translatorcomment>Názov súboru podcastu</translatorcomment>
        <translation>Film OpenBoardu</translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>verzia: </translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>Zvýrazňovač je citlivý na tlak</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Password:</source>
        <translation type="vanished">Heslo:</translation>
    </message>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">Prihlásenie na proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">Používateľské meno:</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Description:</source>
        <translation type="vanished">Popis:</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">Názov:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">Publikovať</translation>
    </message>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">Publikovať dokument na internet</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>Moje filmy</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation>Zobraziť aj nabudúce</translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>%1 vytvorených miniatúr...</translation>
    </message>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>Vytvárajú sa ukážky miniatúr...</translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Stránka %0</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Mask</source>
        <translation>Clona</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>Baterka</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>Pravítko</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>Trojuholník</translation>
    </message>
    <message>
        <source>Compass</source>
        <translation>Kružidlo</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>Uhlomer</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>Lupa</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>Whole page</source>
        <translation>Celá stránka</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>Aktualizácia dokumentu</translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>Prosím, počkajte, proces nahrávania sa čoskoro začne...</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>Aktualizácia bola úspešne dokončená!
Reštartujte aplikáciu, aby ste mohli pracovať s aktualizovanými dokumentmi.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Prehľadávať</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>Vyberte priečinok zálohy</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation>súbory si vyžadujú aktualizáciu.</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualizovať</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>Počas aktualizácie sa vyskytla chyba. Súbory to neovplyvnilo.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>Výsledky aktualizácie súborov</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>Umiestnenie zálohy:</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>Prebieha aktualizácia súboru</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Pripomenúť mi neskôr</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>Nahráva sa...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 vyvolané (metóda = %1, stav = %2)</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>Nepodarilo sa prihlásiť na YouTube.</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>Chyba pri nahrávaní videa na YouTube (%1)</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>Prebieha nahrávanie na YouTube %1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Music</source>
        <translation>Hudba</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>Ľudia a blogy</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>Neziskovky a aktivisti</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>Komédia</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Hry</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>Šport</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Nahrať</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>Veda a technika</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>Návody a štýl</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>Vzdelávanie</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>Zábava</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>Cestovanie a udalosti</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>Správy a politika</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>Zvieratá</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>Autá a dopravné prostriedky</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Vyčistiť</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>KB</source>
        <translation>kB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytov</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>– zostáva %4 %5 </translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minút(y)</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>Chyba pri otváraní uloženého súboru: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekúnd</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Chyba pri ukladaní súboru: %1</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Sťahovanie súboru bolo zrušené: %1</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 z(o) %2 – zastavené</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Uložiť súbor</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 z(o) %2 (%3/sek) %4</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Chyba siete: %1</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation>?</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>1 stiahnutý súbor</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1 stiahnuté súbory</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Názov</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>%1 items</source>
        <translatorcomment>2,3,4 položky, 0, &gt;=5 položiek</translatorcomment>
        <translation>%1 položiek</translation>
    </message>
    <message>
        <source>Earlier Today</source>
        <translation>Dnes</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Hľadať</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>Reload All Tabs</source>
        <translation>Obnoviť všetky karty</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Obnoviť kartu</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>Duplikovať kartu</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Zatvoriť kartu</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Zatvoriť &amp;ostané karty</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>Nová &amp;karta</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>(Untitled)</source>
        <translation>(Bez názvu)</translation>
    </message>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Nedávno zatvorené karty</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Recent Searches</source>
        <translation>Nedávne vyhľadávania</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Vyhľadať</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Žiadne nedávne vyhľadávania</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Vymazať nedávne vyhľadávania</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>Pridať do aktuálneho dokumentu</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Stiahnuť</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>Chyba pri nahrávaní stránky: %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation>Sťahovanie dokumentu PDF: chcete súbor PDF radšej stiahnuť alebo pridať do aktuálneho dokumentu?</translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>Otvoriť na novej karte</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Title</source>
        <translation>Názov</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>Používateľské meno na YouTube</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>Heslo na YouTube</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategória</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publikovať podcast na YouTube</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Kľúčové slová</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;Kliknutím na &quot;Upload&quot; (Nahrať) potvrdzujete, že máte všetky práva k materiálu alebo že máte písomný súhlas vlastníka týchto práv na zverejnenie materiálu na sieti YouTube a že materiál je v súlade s podmienkami využívania služieb siete YouTube, ktorých aktuálne znenie sa nachádza na adrese  &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation>Po reštarte obnoviť prihlasovacie údaje</translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>Fine</source>
        <translation>Tenká</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Stredne  hrubá</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>Hrubá</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Priehľadnosť</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Šírka čiary</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation>Na svetlom pozadí</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>Pero je citlivé na tlak</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Na tmavom pozadí</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Title</source>
        <translation>Názov</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialóg</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">Dialóg</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">Názov</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="obsolete">E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="obsolete">Autor</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">Popis</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation>Dokumenty OpenBoardu</translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation>Dátum vytvorenia</translation>
    </message>
    <message>
        <source>Update date</source>
        <translation>Dátum úpravy</translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation>Podľa abecedy</translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation>Kritérium triedenia</translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Pen</source>
        <translation>Pero</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programe</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zatvoriť</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Vodorovná</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>Pod tlačidlom zobraziť text</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>Stránku zobraziť v externom prehliadači</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>Predvolené nastavenia</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Sieť</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>Je umiestnený dole (odporúča sa pre tabule)</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Zvýrazňovač</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>Je umiestnený navrchu (odporúča sa pre tablety)</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Virtuálna klávesnica</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Úvodná stránka:</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>Pri spustení programu vyhľadať aktualizáciu</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>Aktualizácia programu</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">Veľkosť tlačidla klávesnice:</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>Paleta pre interaktívne pero</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Zobraziť</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Panel s nástrojmi</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Zvislá</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Predvoľby</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>Verzia:...</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>Licencie</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>Viac obrazoviek</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>Na druhej obrazovke alebo projektore zobraziť obsah internej webovej stránky</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation>Prehodiť ovládaciu obrazovku a zobrazovaciu obrazovku</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Režim</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>Režim pri štarte:</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>Tabuľa</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Pracovná plocha</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>Použ. meno na proxy:</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Poďakovanie</translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation>Nahrávanie z Open-Sankoré</translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation>Zistiť, či pri spustení možno nahrať dáta Open-Sankoré</translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation>Používať systémovú klávesnicu (odporúča sa)</translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation>Veľkosť tlačidla zabudovanej virtuálnej klávesnice:</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Na tmavom pozadí</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Priehľadnosť</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation>Na svetlom pozadí</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation>Vymeniť obrazovku 1. a 2. zobrazenia</translation>
    </message>
    <message>
        <source>Grid</source>
        <translation>Mriežka</translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>Označiť flash</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation>Vyberte flash, ktorý chcete označiť</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>Názov aplikácie</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>Vytvoriť aplikáciu</translation>
    </message>
</context>
</TS>
